@@ -15,22 +15,7 @@
 #endif /* __cplusplus */
 
 /* the installation location prefix from configure */
-#define wxINSTALL_PREFIX "D:/bld/wxwidgets_1643998584664/_h_env/Library"
-
-/* Define to `int' if <sys/types.h> doesn't define.  */
-#define gid_t int
-
-/* Define to `int' if <sys/types.h> doesn't define.  */
-/* #undef mode_t */
-
-/* Define to `long' if <sys/types.h> doesn't define.  */
-/* #undef off_t */
-
-/* Define to `int' if <sys/types.h> doesn't define.  */
-#define pid_t int
-
-/* Define to `unsigned' if <sys/types.h> doesn't define.  */
-/* #undef size_t */
+#define wxINSTALL_PREFIX "D:/bld/wxwidgets_1654558247820/_h_env/Library"
 
 /* Define if ssize_t type is available.  */
 /* #undef HAVE_SSIZE_T */
@@ -43,9 +28,6 @@
 /* #undef _GNU_SOURCE */
 #endif
 
-/* Define to `int' if <sys/types.h> doesn't define.  */
-#define uid_t int
-
 /* Define if your processor stores words with the most significant
    byte first (like Motorola and SPARC, unlike Intel and VAX).  */
 /* #undef WORDS_BIGENDIAN */
@@ -234,6 +216,8 @@
 
 #define wxUSE_SECRETSTORE 1
 
+#define wxUSE_SPELLCHECK 1
+
 #define wxUSE_STDPATHS 1
 
 #define wxUSE_TEXTBUFFER 1
@@ -328,7 +312,7 @@
 
 #define wxUSE_XRC 1
 
-#define wxUSE_XML       wxUSE_XRC
+#define wxUSE_XML 1
 
 #define wxUSE_AUI 1
 
@@ -348,6 +332,8 @@
 
 #define wxUSE_WEBVIEW_EDGE 0
 
+#define wxUSE_WEBVIEW_EDGE_STATIC 0
+
 #if (defined(__WXGTK__) && !defined(__WXGTK3__)) || defined(__WXOSX__)
 #define wxUSE_WEBVIEW_WEBKIT 1
 #else
@@ -623,6 +609,10 @@
 
 #define wxUSE_LIBTIFF 1
 
+#define wxUSE_NANOSVG 1
+
+#define wxUSE_NANOSVG_EXTERNAL 0
+
 #define wxUSE_TGA 1
 
 #define wxUSE_GIF 1
@@ -833,12 +823,6 @@
  */
 /* #undef HAVE_BROKEN_LIBSTDCXX_VISIBILITY */
 
-/*
- * The built-in regex supports advanced REs in additional to POSIX's basic
- * and extended. Your system regex probably won't support this, and in this
- * case WX_NO_REGEX_ADVANCED should be defined.
- */
-/* #undef WX_NO_REGEX_ADVANCED */
 /*
  * On GNU systems use re_search instead of regexec, since the latter does a
  * strlen on the search text affecting the performance of some operations.
@@ -1000,9 +984,6 @@
 /* Define if you have snprintf() */
 /* #undef HAVE_SNPRINTF */
 
-/* Define if you have snprintf() declaration in the header */
-/* #undef HAVE_SNPRINTF_DECL */
-
 /* Define if you have a snprintf() which supports positional arguments
    (defined in the unix98 standard) */
 /* #undef HAVE_UNIX98_PRINTF */
@@ -1025,9 +1006,6 @@
 /* Define if you have vsnprintf() */
 /* #undef HAVE_VSNPRINTF */
 
-/* Define if you have vsnprintf() declaration in the header */
-/* #undef HAVE_VSNPRINTF_DECL */
-
 /* Define if you have a _broken_ vsnprintf() declaration in the header,
  * with 'char*' for the 3rd parameter instead of 'const char*' */
 /* #undef HAVE_BROKEN_VSNPRINTF_DECL */
@@ -1039,9 +1017,6 @@
 /* Define if you have vsscanf() */
 #define HAVE_VSSCANF 1
 
-/* Define if you have vsscanf() declaration in the header */
-/* #undef HAVE_VSSCANF_DECL */
-
 /* Define if you have usleep() */
 /* #undef HAVE_USLEEP */
 
